==> hboard-1.0-rc1.tar.gz: hboard/config_ok.php <==
<?php

/* EtchiBoard Version 1.0
     config_ok.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("skin/$admin_data[skin]/style.php"); // Ų
include ("lib/message.inc"); // ޽ function

 if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  Ű  
  PrintMessage(" Ű ã  ϴ.", "error");
 }

 else {
 // óϱ... -_-

$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

/* йȣ Ȯ,  ִٸ   ׳ ó */
 if($admin_pass == "") $admin_pass = $admin_data[passwd];
 else $admin_pass = crypt($admin_pass, HB);

/* html 뿩.. yes t, no f ó */
 if($use_html == "yes") $use_html = "t";
 else $use_html = "f";

// ó

  mysql_query("update hboard_db_admin set passwd='${admin_pass}', title_text='${title_text}', app='${article_per_page}', skin='${board_skin}', fileup_max='${fileup_max}', html_tag='${use_html}', include_top='${include_up}', include_bottom='${include_bt}', bgimage='${bgimage}', width_max='${width_max}', lang='${lang}', article_max='${article_max}'") or die("ͺ̽  ߻!");

//   ּ ó (%  &amp; ;;;)
$from = str_replace("_and_", "&amp;", $from);

// ó ;
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Query Completed</title>
</head>

<body>
<script language="JavaScript" type="">
window.opener.location.href = "<?=$from?>";
window.close();
</script>
</body>
</html>

<?php
 mysql_close($dbconnect);
}
?>

==> hboard-1.0.1.tar.gz: hboard/config_ok.php <==
<?php

/* EtchiBoard Version 1.0
     config_ok.php
     http://etchibbs.kldp.net */

/***************************************************************************
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 *
 ***************************************************************************/

include ("lib/admin.inc"); //  ȯ漳
include ("skin/$admin_data[skin]/style.php"); // Ų
include ("lib/message.inc"); // ޽ function

 if($HTTP_COOKIE_VARS["hboard_admin_login"] != $admin_data[passwd]) {
 //  Ű  
  PrintMessage(" Ű ã  ϴ.", "error");
 }

 else {
 // óϱ... -_-

$dbconnect = mysql_connect($hostname, $username, $dbpass);
 mysql_select_db($dbname);

/* йȣ Ȯ,  ִٸ   ׳ ó */
 if($admin_pass == "") $admin_pass = $admin_data[passwd];
 else $admin_pass = crypt($admin_pass, HB);

// ó

  mysql_query("update hboard_db_admin set passwd='${admin_pass}', title_text='${title_text}', app='${article_per_page}', skin='${board_skin}', fileup_max='${fileup_max}', html_tag='${use_html}', include_top='${include_up}', include_bottom='${include_bt}', bgimage='${bgimage}', width_max='${width_max}', lang='${lang}', article_max='${article_max}', titlebar='${titlebar}', autolink='${autolink}', backdrum='${backdrum}'") or die("ͺ̽  ߻!");

//   ּ ó (%  &amp; ;;;)
$from = str_replace("_and_", "&amp;", $from);

// ó ;
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN">
<html>
<head>
<title>Query Completed</title>
</head>

<body>
<script language="JavaScript" type="">
window.opener.location.href = "<?php echo $from?>";
window.close();
</script>
</body>
</html>

<?php
 mysql_close($dbconnect);
}
?>
